abstract class IPermissionManager {
  ///检查精准定位
  Future<bool> requestLocationPermission();

  Future<bool> requestBluetoothConnectPermission();
  Future<bool> requestBluetoothScanPermission();
  Future<bool> requestBluetoothAdvertisePermission();
  Future<bool> requestInstallPackagesPermission();
  Future<bool> requestCameraPermissions();
  Future<bool> requestPermissions(List<String> permissions);
  Future<bool> openAppSettingsAsync();
}
